@@ -11,17 +11,25 @@ def test_vacancy():
     coords = [[0, 0, 0], [0.25, 0.25, 0.25]]
     elements = ["Si", "Si"]
     Si = Atoms(lattice_mat=box, coords=coords, elements=elements)
-    vacs = Vacancy(atoms=Si).generate_defects(enforce_c_size=10.0)
+    v = Vacancy(atoms=Si)
+    vacs = v.generate_defects(enforce_c_size=10.0)
+    td = vacs[0].to_dict()
+    fd = Vacancy.from_dict(td)
     # print ( len(vacs),(vacs[0].to_dict()["defect_structure"].num_atoms))
     # print (vacs[0].to_dict()["defect_structure"])
-    assert (len(vacs), vacs[0].to_dict()["defect_structure"].num_atoms) == (1, 53)
+    assert (
+        len(vacs),
+        Atoms.from_dict(vacs[0].to_dict()["defect_structure"]).num_atoms,
+    ) == (1, 53)
 
 
 def test_2d():
     p = Poscar.from_file(C).atoms
     vacs = Vacancy(atoms=p).generate_defects(enforce_c_size=10.0, extend=1)
     # print (vacs[0]._defect_structure)
-    assert (vacs[0].to_dict()["defect_structure"]).num_atoms == 49
+    assert (
+        Atoms.from_dict(vacs[0].to_dict()["defect_structure"]).num_atoms == 49
+    )
 
 
 # test_2d()
